# -*- coding: utf-8 -*-

from django.contrib import admin
from newsletter_subscriptions.models import Subscription

try:
    from import_export.admin import ExportMixin
except ImportError:
    ExportMixin = None
else:
    from newsletter_subscriptions.resources import SubscriptionResource


class SubscriptionAdmin(admin.ModelAdmin):
    date_hierarchy = 'creation_date'
    list_display = [
        'email',
        'first_name',
        'last_name',
        'creation_date',
    ]
    list_filter = [
        'creation_date',
    ]
    search_fields = [
        'first_name',
        'last_name',
        'email',
    ]
    actions_on_top = False
    actions_on_bottom = True


if ExportMixin:
    SubscriptionAdmin = type(SubscriptionAdmin)(
        'SubscriptionAdmin',
        (ExportMixin, SubscriptionAdmin), {
            'resource_class': SubscriptionResource,
        })


admin.site.register(Subscription, SubscriptionAdmin)
