# -*- coding: utf-8 -*-

import importlib

from crispy_forms.helper import FormHelper
from crispy_forms_foundation.layout import (
    Layout,
    Field,
    Row,
    Column,
    ButtonHolder,
    Submit,
)

from django.core.urlresolvers import reverse_lazy
from django.utils.translation import ugettext_lazy
from django.utils.functional import cached_property

from django.conf import settings
from django.test.signals import setting_changed


class FormHelperFinder(object):
    def __init__(self, setting_name):
        self.setting_name = setting_name
        setting_changed.connect(self._on_setting_changed, weak=False)

    @cached_property
    def form_helper_module(self):
        module_name = getattr(settings, self.setting_name, None)
        if module_name is None:
            return None
        return importlib.import_module(module_name)

    def _on_setting_changed(self, sender, setting, **kw):
        if setting == self.setting_name:
            if self.setting_name in self.__dict__:
                del self.__dict__[self.setting_name]

    def __call__(self, default):
        try:
            return getattr(self.form_helper_module, default.__name__)
        except AttributeError:
            pass
        return default


helper_finder = FormHelperFinder('NEWSLETTER_SUBSCRIPTIONS_HELPERS_MODULE')


class SubscriptionFormHelper(FormHelper):
    form_id = 'nl-subscribe'
    form_action = reverse_lazy('newsletter-subscribe-form')
    layout = Layout(
        Row(
            Column('nl_email',
                   css_class='small-12 large-8 large-centered',
                   placeholder=ugettext_lazy('email')),
        ),
        Row(
            Column('opt_in'),
        ),
        Row(
            Column(
                ButtonHolder(Submit('submit', u'I subscribe', css_class="chocolate1")),
            ),
        ),
    )


class InlineSubscriptionFormHelper(SubscriptionFormHelper):
    layout = Layout(
        Row(
            Column(
                Field('nl_email', placeholder=ugettext_lazy('email address'), css_class='radius'),
                css_class='small-8 medium-7 columns email-field '
                'hidelabel'
            ),
            Column(
                ButtonHolder(
                    Submit('nl_submit',
                           ugettext_lazy('Keep me posted'),
                           css_class='medium button radius')
                ),
                css_class='small-4 medium-4 right columns'
                'perspective'
            ),
            Column(
                Field('opt_in', css_class='radius'),
                css_class='small-8 small-centered medium-7 columns'
                'clear nl-accept'
            ),
        ),
    )


class AlternativeInlineSubscriptionFormHelper(SubscriptionFormHelper):
    attrs = {
        'class': 'inline',
    }
    layout = Layout(
        Row(
            Column(
                Field('nl_email', placeholder=ugettext_lazy(u'Email')),
                css_class='large-7 columns',
            ),
            Column(
                ButtonHolder(
                    Submit('nl_submit', ugettext_lazy(u'I subscribe'), css_class='radius postfix')
                ),
                css_class='large-5 columns'
            ),
            css_class='collapse'
        ),
        Row(
            Column('opt_in', css_class='checkbox-input large-12 columns'),
        ),
    )
